#!/bin/bash
#
# author           : George Vlahavas (vlahavas~AT~gmail~DOT~com, gapan@zenwalk forums)
# project web page : http://www.armagetronad.net/
# source           : http://prdownloads.sourceforge.net/armagetronad/armagetronad-0.2.8.2.1.src.tar.gz

# Package name
NAME="armagetronad"
# Package version
VERSION="0.2.8.2.1"
# Source code URL
SOURCE="http://prdownloads.sourceforge.net/armagetronad/armagetronad-$VERSION.src.tar.gz?download"
# ./configure options
CONFIGOPTIONS="--prefix=/usr --sysconfdir=/usr/share --disable-games --disable-etc --enable-music"
# Files that should be placed in /usr/doc/package-version/
DOCS="AUTHORS COPYING ChangeLog INSTALL NEWS README README-DEVELOPER README-KDevelop3_0 README-SDL src/doc/Content_Creation/Howto-Maps.txt"

CWD=`pwd`
PKG="$CWD/$NAME-install"
ARCH="i686"
CPU="i686"
BUILD="48.1"

rm -rf $PKG
mkdir -p $PKG

# Create package install directory
mkdir $PKG/install

# Create the slack-desc file
cat > $PKG/install/slack-desc << END
$NAME: armagetronad is a 3d light cycle game
$NAME:
$NAME: Armagetron is a multiplayer game in 3d that attempts to emulate and
$NAME: expand on the lightcycle sequence from the movie Tron. It's an old
$NAME: school arcade game slung into the 21st century. Highlights include
$NAME: a customizable playing arena, HUD, unique graphics, and AI bots.
$NAME: For the more advanced player there are new game modes and a wide
$NAME: variety of physics settings to tweak as well.
$NAME:
$NAME:
$NAME:
END

# Check to see if source is present. If it's not, download it
rm -rf $NAME-$VERSION
if [ -f $NAME-$VERSION.src.tar.gz ]; then
	echo "Source file already here, no need to download";
else
 	echo "Downloading source"
	wget -c $SOURCE
fi

# Unpack source
tar xvzf $NAME-$VERSION.src.tar.gz

#
# building-computer dependent: the number of parallel 'jobs' of 'make'
#
# 'heavy' computer: 6 build-jobs at once
#
#numjobs='-j6'
#
# 'light' computer: 2 build-jobs at once
#
numjobs='-j2'

# Configure and make
cd $NAME-$VERSION
export CFLAGS="-O2 -march=$ARCH -mtune=$CPU"
export CXXFLAGS="-O2 -march=$ARCH -mtune=$CPU"
./configure $CONFIGOPTIONS
make $numjobs

# Install on temporary directory
make install DESTDIR=$PKG

# Remove unwanted files
rm -rf $PKG/usr/share/applnk
rm -rf $PKG/usr/share/icons
rm -rf $PKG/usr/bin/armagetronad-uninstall

# Fix the desktop entry
sed -i -e 's/.png//' $PKG/usr/share/armagetronad/desktop/armagetronad.desktop
sed -i -e 's/Categories=.*/Categories=Game;ActionGame;/' $PKG/usr/share/armagetronad/desktop/armagetronad.desktop

# Strip binaries
cd $PKG
find . | xargs file | grep ELF | cut -f 1 -d : | xargs strip --strip-unneeded 2> /dev/null

# Copy Docs
mkdir -p $PKG/usr/doc/$NAME-$VERSION
cd $CWD/$NAME-$VERSION
cp -a $DOCS $PKG/usr/doc/$NAME-$VERSION

# Move html documentation with all the other docs
mv $PKG/usr/share/doc/armagetronad/html $PKG/usr/doc/$NAME-$VERSION
rm -rf $PKG/usr/share/doc

# Make symlinks
mkdir -p $PKG/usr/share/applications
cd $PKG/usr/share/applications
ln -sf ../armagetronad/desktop/armagetronad.desktop armagetronad.desktop
mkdir -p $PKG/usr/share/icons/hicolor/48x48/apps
cd $PKG/usr/share/icons/hicolor/48x48/apps
ln -sf ../../../../armagetronad/desktop/icons/large/armagetronad.png armagetronad.png
mkdir -p $PKG/usr/share/icons/hicolor/32x32/apps
cd $PKG/usr/share/icons/hicolor/32x32/apps
ln -sf ../../../../armagetronad/desktop/icons/medium/armagetronad.png armagetronad.png
mkdir -p $PKG/usr/share/icons/hicolor/16x16/apps
cd $PKG/usr/share/icons/hicolor/16x16/apps
ln -sf ../../../../armagetronad/desktop/icons/small/armagetronad.png armagetronad.png

# Compress the man page(s)
find $PKG/usr/man -type f -exec gzip -9 {} \;

# Add the build-file in the package
mkdir -p $PKG/usr/src/$NAME-$VERSION
cp "$CWD/build-$NAME.sh" "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"
chmod a+x "$PKG/usr/src/$NAME-$VERSION/build-$NAME.sh"

# Make sure ownerships and permissions are sane
cd $PKG
chown -R root:root .
find . -perm 666 -exec chmod 644 {} \;
find . -perm 664 -exec chmod 644 {} \;
find . -perm 600 -exec chmod 644 {} \;
find . -perm 444 -exec chmod 644 {} \;
find . -perm 400 -exec chmod 644 {} \;
find . -perm 440 -exec chmod 644 {} \;
find . -perm 777 -exec chmod 755 {} \;
find . -perm 775 -exec chmod 755 {} \;
find . -perm 511 -exec chmod 755 {} \;
find . -perm 711 -exec chmod 755 {} \;
find . -perm 555 -exec chmod 755 {} \;

# Make the package
makepkg -l y -c n $CWD/$NAME-$VERSION-$ARCH-$BUILD.tgz

# Calculate md5sum
cd $CWD/
md5sum $NAME-$VERSION-$ARCH-$BUILD.tgz > $NAME-$VERSION-$ARCH-$BUILD.md5

# Remove source-code and temporary install directories
# since they are not needed anymore
rm -rf $CWD/$NAME-$VERSION
rm -rf $PKG
